local enable_debug_prints = true
-------------------------------------------------------------------------------
-- Faction adding code. Don't touch this unless you know what your doing. :) --
-------------------------------------------------------------------------------
local function debug_log(...)
	if enable_debug_prints then
		log(...)
	end
end

local function string_list_to_idstring_list(list)
	local output = {}
	for key, value in pairs(list) do
		output[key] = Idstring(value)
	end
	return output
end

local function add_faction(faction_name, chatter, prefixes, groups, difficulty_specific)
	debug_log("[Faction Adder] Adding Faction: " .. faction_name)
	LevelsTweakData.LevelType[faction_name] = faction_name
	-- BeardLib cares about this. Even though they're all just glorified paths to strings. :sader:
	Hooks:PostHook(LevelsTweakData, "init", "unique_special_level_group_hook_" .. faction_name, function(self)
		self.ai_groups[faction_name] = faction_name
	end)

	-- Setup unit category hook.
	Hooks:PostHook(GroupAITweakData, "_init_unit_categories", "unique_special_faction_hook_" .. faction_name, function(groupai_td, difficulty_index)
		-- Get difficulty specific unit lists.
		local difficulty_specific_groups = difficulty_specific[difficulty_index]
		if difficulty_specific_groups then
			debug_log("[Faction Adder] Found Difficulty Specific: " .. tostring(difficulty_index))
			for category_name, unit_list in pairs(difficulty_specific_groups) do
				groups[category_name] = unit_list
			end
		end

		-- Add our faction group variants.
		for category_name, category_data in pairs(groupai_td.unit_categories) do
			local unit_list = groups[category_name]

			if unit_list then
				debug_log("[Faction Adder] Custom Group: " .. category_name)
				category_data.unit_types[faction_name] = string_list_to_idstring_list(unit_list)
			elseif category_data.unit_types.america then
				debug_log("[Faction Adder] No Custom Group: " .. category_name)
				category_data.unit_types[faction_name] = category_data.unit_types.america
			end
		end
	end)

	-- Setup the function used to set prefixes and chatter.
	CharacterTweakData["_init_region_" .. faction_name] = function(self)
		self:_init_region_america()

		self._default_chatter = chatter or self._default_chatter
		for key, value in pairs(prefixes) do
			self._unit_prefixes[key] = value
		end
	end
end

--------------------------
-- Faction Setup Stuff --
--------------------------

-- Define the factions internal name.
local faction_name = "all"

-- Define voice data.
local chatter = "dispatch_generic_message"
local prefixes = {
	cop = "l",
	swat = "l",
	heavy_swat = "l",
	taser = "tsr",
	cloaker = "clk",
	bulldozer = "bdz",
	medic = "mdc"
}

-- Define generic units.
-- If your really cool you can add groups from rebalances here as well and it'll handle that.
-- If you don't specify a group it'll just default to a copy of `america` so that shit doesn't explode.
local groups = {
	spooc = {
		"units/payday2/characters/ene_spook_1/ene_spook_1",
		"units/pd2_dlc_bex/characters/ene_swat_cloaker_policia_federale/ene_swat_cloaker_policia_federale",
		"units/pd2_dlc_bph/characters/ene_murkywater_cloaker/ene_murkywater_cloaker",
		"units/pd2_dlc_hvh/characters/ene_spook_hvh_1/ene_spook_hvh_1",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_spooc_asval_smg/ene_akan_fbi_spooc_asval_smg",
		"units/pd2_dlc_gitgud/characters/ene_zeal_cloaker/ene_zeal_cloaker"
	},
	CS_cop_C45_R870 = {
		"units/payday2/characters/ene_cop_1/ene_cop_1",
		"units/payday2/characters/ene_cop_3/ene_cop_3",
		"units/payday2/characters/ene_cop_4/ene_cop_4"
	},
	CS_cop_stealth_MP5 = {
		"units/payday2/characters/ene_cop_2/ene_cop_2"
	},
	CS_swat_MP5 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	CS_swat_R870 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	CS_heavy_M4 = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	CS_heavy_R870  = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	CS_heavy_M4_w = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	CS_tazer = {
		"units/payday2/characters/ene_tazer_1/ene_tazer_1",
		"units/pd2_dlc_gitgud/characters/ene_zeal_tazer/ene_zeal_tazer",
		"units/pd2_dlc_mad/characters/ene_akan_cs_tazer_ak47_ass/ene_akan_cs_tazer_ak47_ass",
		"units/pd2_dlc_hvh/characters/ene_tazer_hvh_1/ene_tazer_hvh_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_tazer/ene_murkywater_tazer",
		"units/pd2_dlc_bex/characters/ene_swat_tazer_policia_federale/ene_swat_tazer_policia_federale"
	},
	CS_shield = {
		"units/payday2/characters/ene_shield_2/ene_shield_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_shield/ene_zeal_swat_shield",
		"units/payday2/characters/ene_shield_1/ene_shield_1",
		"units/pd2_dlc_mad/characters/ene_akan_cs_shield_c45/ene_akan_cs_shield_c45",
		"units/payday2/characters/ene_city_shield/ene_city_shield",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_sr2_smg/ene_akan_fbi_shield_sr2_smg",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_dw_sr2_smg/ene_akan_fbi_shield_dw_sr2_smg",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_1/ene_shield_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_2/ene_shield_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_shield/ene_murkywater_shield",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_c45/ene_swat_shield_policia_federale_c45",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_mp9/ene_swat_shield_policia_federale_mp9"
	},
	FBI_suit_C45_M4 = {
		"units/payday2/characters/ene_fbi_1/ene_fbi_1",
		"units/payday2/characters/ene_fbi_2/ene_fbi_2"
	},
	FBI_suit_M4_MP5 = {
		"units/payday2/characters/ene_fbi_2/ene_fbi_2",
		"units/payday2/characters/ene_fbi_3/ene_fbi_3"
	},
	FBI_suit_stealth_MP5 = {
		"units/payday2/characters/ene_fbi_3/ene_fbi_3"
	},
	FBI_swat_M4 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	FBI_swat_R870 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	FBI_heavy_G36 = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_heavy_R870  = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},

	FBI_heavy_G36_w = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_shield = {
		"units/payday2/characters/ene_shield_2/ene_shield_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_shield/ene_zeal_swat_shield",
		"units/payday2/characters/ene_shield_1/ene_shield_1",
		"units/pd2_dlc_mad/characters/ene_akan_cs_shield_c45/ene_akan_cs_shield_c45",
		"units/payday2/characters/ene_city_shield/ene_city_shield",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_sr2_smg/ene_akan_fbi_shield_sr2_smg",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_dw_sr2_smg/ene_akan_fbi_shield_dw_sr2_smg",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_1/ene_shield_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_2/ene_shield_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_shield/ene_murkywater_shield",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_c45/ene_swat_shield_policia_federale_c45",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_mp9/ene_swat_shield_policia_federale_mp9"
	},
	FBI_tank = {
		"units/payday2/characters/ene_bulldozer_1/ene_bulldozer_1",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_2/ene_zeal_bulldozer_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_r870/ene_akan_fbi_tank_r870",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_1/ene_bulldozer_hvh_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_2/ene_murkywater_bulldozer_2",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_r870/ene_swat_dozer_policia_federale_r870",
		"units/payday2/characters/ene_bulldozer_2/ene_bulldozer_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_3/ene_zeal_bulldozer_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_saiga/ene_akan_fbi_tank_saiga",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_2/ene_bulldozer_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_3/ene_murkywater_bulldozer_3",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_saiga/ene_swat_dozer_policia_federale_saiga",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_m249/ene_swat_dozer_policia_federale_m249",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_4/ene_murkywater_bulldozer_4",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_3/ene_bulldozer_hvh_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_rpk_lmg/ene_akan_fbi_tank_rpk_lmg",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer/ene_zeal_bulldozer",
		"units/payday2/characters/ene_bulldozer_3/ene_bulldozer_3",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun_classic/ene_bulldozer_minigun_classic",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun/ene_bulldozer_minigun",
		"units/pd2_dlc_drm/characters/ene_bulldozer_medic/ene_bulldozer_medic",
		"units/payday2/characters/ene_bulldozer_4/ene_bulldozer_4",
		"units/pd2_dlc_help/characters/ene_zeal_bulldozer_halloween/ene_zeal_bulldozer_halloween",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_1/ene_murkywater_bulldozer_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_medic/ene_murkywater_bulldozer_medic",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_minigun/ene_swat_dozer_policia_federale_minigun",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_medic_policia_federale/ene_swat_dozer_medic_policia_federale"
	},
	medic_M4 = {
		"units/payday2/characters/ene_medic_m4/ene_medic_m4",
		"units/payday2/characters/ene_medic_r870/ene_medic_r870",
		"units/pd2_dlc_mad/characters/ene_akan_medic_ak47_ass/ene_akan_medic_ak47_ass",
		"units/pd2_dlc_hvh/characters/ene_medic_hvh_m4/ene_medic_hvh_m4",
		"units/pd2_dlc_bph/characters/ene_murkywater_medic/ene_murkywater_medic",
		"units/pd2_dlc_bex/characters/ene_swat_medic_policia_federale/ene_swat_medic_policia_federale"
	},
	medic_R870 = {
		"units/payday2/characters/ene_medic_m4/ene_medic_m4",
		"units/payday2/characters/ene_medic_r870/ene_medic_r870",
		"units/pd2_dlc_mad/characters/ene_akan_medic_ak47_ass/ene_akan_medic_ak47_ass",
		"units/pd2_dlc_hvh/characters/ene_medic_hvh_m4/ene_medic_hvh_m4",
		"units/pd2_dlc_bph/characters/ene_murkywater_medic/ene_murkywater_medic",
		"units/pd2_dlc_bex/characters/ene_swat_medic_policia_federale/ene_swat_medic_policia_federale"
	},
	Phalanx_minion = {
		"units/pd2_dlc_vip/characters/ene_phalanx_1/ene_phalanx_1"
	},
	Phalanx_vip = {
		"units/pd2_dlc_vip/characters/ene_vip_1/ene_vip_1"
	}
}

-- Define difficulty specific units.
local difficulty_specific = {}

-- Overkill --
difficulty_specific[5] = {
	FBI_tank = {
		"units/payday2/characters/ene_bulldozer_1/ene_bulldozer_1",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_2/ene_zeal_bulldozer_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_r870/ene_akan_fbi_tank_r870",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_1/ene_bulldozer_hvh_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_2/ene_murkywater_bulldozer_2",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_r870/ene_swat_dozer_policia_federale_r870",
		"units/payday2/characters/ene_bulldozer_2/ene_bulldozer_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_3/ene_zeal_bulldozer_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_saiga/ene_akan_fbi_tank_saiga",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_2/ene_bulldozer_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_3/ene_murkywater_bulldozer_3",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_saiga/ene_swat_dozer_policia_federale_saiga",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_m249/ene_swat_dozer_policia_federale_m249",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_4/ene_murkywater_bulldozer_4",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_3/ene_bulldozer_hvh_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_rpk_lmg/ene_akan_fbi_tank_rpk_lmg",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer/ene_zeal_bulldozer",
		"units/payday2/characters/ene_bulldozer_3/ene_bulldozer_3",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun_classic/ene_bulldozer_minigun_classic",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun/ene_bulldozer_minigun",
		"units/pd2_dlc_drm/characters/ene_bulldozer_medic/ene_bulldozer_medic",
		"units/payday2/characters/ene_bulldozer_4/ene_bulldozer_4",
		"units/pd2_dlc_help/characters/ene_zeal_bulldozer_halloween/ene_zeal_bulldozer_halloween",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_1/ene_murkywater_bulldozer_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_medic/ene_murkywater_bulldozer_medic",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_minigun/ene_swat_dozer_policia_federale_minigun",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_medic_policia_federale/ene_swat_dozer_medic_policia_federale"
	}
}

-- Mayhem --
difficulty_specific[6] = {
	FBI_swat_M4 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	FBI_swat_R870 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	FBI_heavy_G36 = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_heavy_R870  = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_shield = {
		"units/payday2/characters/ene_shield_2/ene_shield_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_shield/ene_zeal_swat_shield",
		"units/payday2/characters/ene_shield_1/ene_shield_1",
		"units/pd2_dlc_mad/characters/ene_akan_cs_shield_c45/ene_akan_cs_shield_c45",
		"units/payday2/characters/ene_city_shield/ene_city_shield",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_sr2_smg/ene_akan_fbi_shield_sr2_smg",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_dw_sr2_smg/ene_akan_fbi_shield_dw_sr2_smg",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_1/ene_shield_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_2/ene_shield_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_shield/ene_murkywater_shield",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_c45/ene_swat_shield_policia_federale_c45",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_mp9/ene_swat_shield_policia_federale_mp9"
	},
	FBI_tank = {
		"units/payday2/characters/ene_bulldozer_1/ene_bulldozer_1",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_2/ene_zeal_bulldozer_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_r870/ene_akan_fbi_tank_r870",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_1/ene_bulldozer_hvh_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_2/ene_murkywater_bulldozer_2",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_r870/ene_swat_dozer_policia_federale_r870",
		"units/payday2/characters/ene_bulldozer_2/ene_bulldozer_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_3/ene_zeal_bulldozer_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_saiga/ene_akan_fbi_tank_saiga",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_2/ene_bulldozer_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_3/ene_murkywater_bulldozer_3",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_saiga/ene_swat_dozer_policia_federale_saiga",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_m249/ene_swat_dozer_policia_federale_m249",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_4/ene_murkywater_bulldozer_4",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_3/ene_bulldozer_hvh_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_rpk_lmg/ene_akan_fbi_tank_rpk_lmg",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer/ene_zeal_bulldozer",
		"units/payday2/characters/ene_bulldozer_3/ene_bulldozer_3",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun_classic/ene_bulldozer_minigun_classic",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun/ene_bulldozer_minigun",
		"units/pd2_dlc_drm/characters/ene_bulldozer_medic/ene_bulldozer_medic",
		"units/payday2/characters/ene_bulldozer_4/ene_bulldozer_4",
		"units/pd2_dlc_help/characters/ene_zeal_bulldozer_halloween/ene_zeal_bulldozer_halloween",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_1/ene_murkywater_bulldozer_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_medic/ene_murkywater_bulldozer_medic",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_minigun/ene_swat_dozer_policia_federale_minigun",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_medic_policia_federale/ene_swat_dozer_medic_policia_federale"
	}
}

-- Death Wish --
difficulty_specific[7] = {
	FBI_swat_M4 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	FBI_swat_R870 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	FBI_heavy_G36 = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_heavy_R870  = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_shield = {
		"units/payday2/characters/ene_shield_2/ene_shield_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_shield/ene_zeal_swat_shield",
		"units/payday2/characters/ene_shield_1/ene_shield_1",
		"units/pd2_dlc_mad/characters/ene_akan_cs_shield_c45/ene_akan_cs_shield_c45",
		"units/payday2/characters/ene_city_shield/ene_city_shield",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_sr2_smg/ene_akan_fbi_shield_sr2_smg",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_dw_sr2_smg/ene_akan_fbi_shield_dw_sr2_smg",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_1/ene_shield_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_2/ene_shield_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_shield/ene_murkywater_shield",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_c45/ene_swat_shield_policia_federale_c45",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_mp9/ene_swat_shield_policia_federale_mp9"
	},
	FBI_tank = {
		"units/payday2/characters/ene_bulldozer_1/ene_bulldozer_1",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_2/ene_zeal_bulldozer_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_r870/ene_akan_fbi_tank_r870",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_1/ene_bulldozer_hvh_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_2/ene_murkywater_bulldozer_2",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_r870/ene_swat_dozer_policia_federale_r870",
		"units/payday2/characters/ene_bulldozer_2/ene_bulldozer_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_3/ene_zeal_bulldozer_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_saiga/ene_akan_fbi_tank_saiga",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_2/ene_bulldozer_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_3/ene_murkywater_bulldozer_3",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_saiga/ene_swat_dozer_policia_federale_saiga",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_m249/ene_swat_dozer_policia_federale_m249",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_4/ene_murkywater_bulldozer_4",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_3/ene_bulldozer_hvh_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_rpk_lmg/ene_akan_fbi_tank_rpk_lmg",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer/ene_zeal_bulldozer",
		"units/payday2/characters/ene_bulldozer_3/ene_bulldozer_3",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun_classic/ene_bulldozer_minigun_classic",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun/ene_bulldozer_minigun",
		"units/pd2_dlc_drm/characters/ene_bulldozer_medic/ene_bulldozer_medic",
		"units/payday2/characters/ene_bulldozer_4/ene_bulldozer_4",
		"units/pd2_dlc_help/characters/ene_zeal_bulldozer_halloween/ene_zeal_bulldozer_halloween",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_1/ene_murkywater_bulldozer_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_medic/ene_murkywater_bulldozer_medic",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_minigun/ene_swat_dozer_policia_federale_minigun",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_medic_policia_federale/ene_swat_dozer_medic_policia_federale"
	}
}

-- Death Sentence --
difficulty_specific[8] = {
	spooc = {
		"units/payday2/characters/ene_spook_1/ene_spook_1",
		"units/pd2_dlc_bex/characters/ene_swat_cloaker_policia_federale/ene_swat_cloaker_policia_federale",
		"units/pd2_dlc_bph/characters/ene_murkywater_cloaker/ene_murkywater_cloaker",
		"units/pd2_dlc_hvh/characters/ene_spook_hvh_1/ene_spook_hvh_1",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_spooc_asval_smg/ene_akan_fbi_spooc_asval_smg",
		"units/pd2_dlc_gitgud/characters/ene_zeal_cloaker/ene_zeal_cloaker"
	},
	CS_swat_MP5 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	CS_swat_R870 = {
		"units/payday2/characters/ene_swat_1/ene_swat_1",
		"units/payday2/characters/ene_swat_2/ene_swat_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat/ene_zeal_swat",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_ak47_ass/ene_akan_cs_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_swat_r870/ene_akan_cs_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_1/ene_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_hvh_2/ene_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light/ene_murkywater_light",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_r870/ene_murkywater_light_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale/ene_swat_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_r870/ene_swat_policia_federale_r870",
		"units/payday2/characters/ene_fbi_swat_1/ene_fbi_swat_1",
		"units/payday2/characters/ene_fbi_swat_2/ene_fbi_swat_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_ak47_ass/ene_akan_fbi_swat_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_r870/ene_akan_fbi_swat_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_1/ene_fbi_swat_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_swat_hvh_2/ene_fbi_swat_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi/ene_murkywater_light_fbi",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_fbi_r870/ene_murkywater_light_fbi_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_fbi/ene_swat_policia_federale_fbi",
		"units/payday2/characters/ene_city_swat_1/ene_city_swat_1",
		"units/payday2/characters/ene_city_swat_2/ene_city_swat_2",
		"units/payday2/characters/ene_city_swat_3/ene_city_swat_3",
		"units/payday2/characters/ene_city_swat_r870/ene_city_swat_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_ak47_ass/ene_akan_fbi_swat_dw_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_swat_dw_r870/ene_akan_fbi_swat_dw_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city/ene_murkywater_light_city",
		"units/pd2_dlc_bph/characters/ene_murkywater_light_city_r870/ene_murkywater_light_city_r870",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city/ene_swat_policia_federale_city",
		"units/pd2_dlc_bex/characters/ene_swat_policia_federale_city_r870/ene_swat_policia_federale_city_r870"
	},
	CS_heavy_M4 = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	CS_heavy_R870  = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	CS_heavy_M4_w = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	CS_tazer = {
		"units/payday2/characters/ene_tazer_1/ene_tazer_1",
		"units/pd2_dlc_gitgud/characters/ene_zeal_tazer/ene_zeal_tazer",
		"units/pd2_dlc_mad/characters/ene_akan_cs_tazer_ak47_ass/ene_akan_cs_tazer_ak47_ass",
		"units/pd2_dlc_hvh/characters/ene_tazer_hvh_1/ene_tazer_hvh_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_tazer/ene_murkywater_tazer",
		"units/pd2_dlc_bex/characters/ene_swat_tazer_policia_federale/ene_swat_tazer_policia_federale"
	},
	CS_shield = {
		"units/payday2/characters/ene_shield_2/ene_shield_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_shield/ene_zeal_swat_shield",
		"units/payday2/characters/ene_shield_1/ene_shield_1",
		"units/pd2_dlc_mad/characters/ene_akan_cs_shield_c45/ene_akan_cs_shield_c45",
		"units/payday2/characters/ene_city_shield/ene_city_shield",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_sr2_smg/ene_akan_fbi_shield_sr2_smg",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_dw_sr2_smg/ene_akan_fbi_shield_dw_sr2_smg",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_1/ene_shield_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_2/ene_shield_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_shield/ene_murkywater_shield",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_c45/ene_swat_shield_policia_federale_c45",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_mp9/ene_swat_shield_policia_federale_mp9"
	},
	FBI_swat_M4 = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_swat_R870 = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_heavy_G36 = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_heavy_R870  = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_heavy_G36_w = {
		"units/payday2/characters/ene_swat_heavy_1/ene_swat_heavy_1",
		"units/payday2/characters/ene_swat_heavy_r870/ene_swat_heavy_r870",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_heavy/ene_zeal_swat_heavy",
		"units/pd2_dlc_drm/characters/ene_zeal_swat_heavy_sniper/ene_zeal_swat_heavy_sniper",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_ak47_ass/ene_akan_cs_heavy_ak47_ass",
		"units/pd2_dlc_mad/characters/ene_akan_cs_heavy_r870/ene_akan_cs_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_1/ene_swat_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_swat_heavy_hvh_r870/ene_swat_heavy_hvh_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy/ene_murkywater_heavy",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_shotgun/ene_murkywater_heavy_shotgun",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale/ene_swat_heavy_policia_federale",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_r870/ene_swat_heavy_policia_federale_r870",
		"units/payday2/characters/ene_fbi_heavy_1/ene_fbi_heavy_1",
		"units/payday2/characters/ene_fbi_heavy_r870/ene_fbi_heavy_r870",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_g36/ene_akan_fbi_heavy_g36",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_heavy_r870/ene_akan_fbi_heavy_r870",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_1/ene_fbi_heavy_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_fbi_heavy_hvh_r870/ene_fbi_heavy_hvh_r870",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi/ene_swat_heavy_policia_federale_fbi",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_r870/ene_swat_heavy_policia_federale_fbi_r870",
		"units/payday2/characters/ene_city_heavy_g36/ene_city_heavy_g36",
		"units/payday2/characters/ene_city_heavy_r870/ene_city_heavy_r870",
		"units/pd2_dlc_bph/characters/ene_murkywater_heavy_g36/ene_murkywater_heavy_g36",
		"units/pd2_dlc_bex/characters/ene_swat_heavy_policia_federale_fbi_g36/ene_swat_heavy_policia_federale_fbi_g36"
	},
	FBI_shield = {
		"units/payday2/characters/ene_shield_2/ene_shield_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_swat_shield/ene_zeal_swat_shield",
		"units/payday2/characters/ene_shield_1/ene_shield_1",
		"units/pd2_dlc_mad/characters/ene_akan_cs_shield_c45/ene_akan_cs_shield_c45",
		"units/payday2/characters/ene_city_shield/ene_city_shield",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_sr2_smg/ene_akan_fbi_shield_sr2_smg",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_shield_dw_sr2_smg/ene_akan_fbi_shield_dw_sr2_smg",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_1/ene_shield_hvh_1",
		"units/pd2_dlc_hvh/characters/ene_shield_hvh_2/ene_shield_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_shield/ene_murkywater_shield",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_c45/ene_swat_shield_policia_federale_c45",
		"units/pd2_dlc_bex/characters/ene_swat_shield_policia_federale_mp9/ene_swat_shield_policia_federale_mp9"
	},
	FBI_tank = {
		"units/payday2/characters/ene_bulldozer_1/ene_bulldozer_1",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_2/ene_zeal_bulldozer_2",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_r870/ene_akan_fbi_tank_r870",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_1/ene_bulldozer_hvh_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_2/ene_murkywater_bulldozer_2",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_r870/ene_swat_dozer_policia_federale_r870",
		"units/payday2/characters/ene_bulldozer_2/ene_bulldozer_2",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer_3/ene_zeal_bulldozer_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_saiga/ene_akan_fbi_tank_saiga",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_2/ene_bulldozer_hvh_2",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_3/ene_murkywater_bulldozer_3",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_saiga/ene_swat_dozer_policia_federale_saiga",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_m249/ene_swat_dozer_policia_federale_m249",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_4/ene_murkywater_bulldozer_4",
		"units/pd2_dlc_hvh/characters/ene_bulldozer_hvh_3/ene_bulldozer_hvh_3",
		"units/pd2_dlc_mad/characters/ene_akan_fbi_tank_rpk_lmg/ene_akan_fbi_tank_rpk_lmg",
		"units/pd2_dlc_gitgud/characters/ene_zeal_bulldozer/ene_zeal_bulldozer",
		"units/payday2/characters/ene_bulldozer_3/ene_bulldozer_3",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun_classic/ene_bulldozer_minigun_classic",
		"units/pd2_dlc_drm/characters/ene_bulldozer_minigun/ene_bulldozer_minigun",
		"units/pd2_dlc_drm/characters/ene_bulldozer_medic/ene_bulldozer_medic",
		"units/payday2/characters/ene_bulldozer_4/ene_bulldozer_4",
		"units/pd2_dlc_help/characters/ene_zeal_bulldozer_halloween/ene_zeal_bulldozer_halloween",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_1/ene_murkywater_bulldozer_1",
		"units/pd2_dlc_bph/characters/ene_murkywater_bulldozer_medic/ene_murkywater_bulldozer_medic",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_policia_federale_minigun/ene_swat_dozer_policia_federale_minigun",
		"units/pd2_dlc_bex/characters/ene_swat_dozer_medic_policia_federale/ene_swat_dozer_medic_policia_federale"
	}
}

-- Add the faction.
add_faction(faction_name, chatter, prefixes, groups, difficulty_specific)